summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldercachedimap.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kmail/kmfoldercachedimap.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmfoldercachedimap.h')
-rw-r--r--kmail/kmfoldercachedimap.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmfoldercachedimap.h b/kmail/kmfoldercachedimap.h
index 87c15f75..dfef783a 100644
--- a/kmail/kmfoldercachedimap.h
+++ b/kmail/kmfoldercachedimap.h
@@ -76,7 +76,7 @@ public:
RefreshCache
};
- DImapTroubleShootDialog( TQWidget* tqparent=0, const char* name=0 );
+ DImapTroubleShootDialog( TQWidget* parent=0, const char* name=0 );
static int run();
@@ -100,8 +100,8 @@ public:
return locateLocal("data", "kmail/dimap" );
}
- /** Usually a tqparent is given. But in some cases there is no
- fitting tqparent object available. Then the name of the folder
+ /** Usually a parent is given. But in some cases there is no
+ fitting parent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderCachedImap(KMFolder* folder, const char* name=0);
virtual ~KMFolderCachedImap();
@@ -110,7 +110,7 @@ public:
void reallyDoClose(const char* owner);
/** Initialize this storage from another one. Used when creating a child folder */
- void initializeFrom( KMFolderCachedImap* tqparent );
+ void initializeFrom( KMFolderCachedImap* parent );
virtual void readConfig();
virtual void writeConfig();
@@ -324,7 +324,7 @@ public:
/**
* Specify an imap path that is used to create the folder on the server
* Otherwise the tqparent folder is used to construct the path
*/
const TQString& imapPathForCreation() { return mImapPathCreation; }
void setImapPathForCreation( const TQString& path ) { mImapPathCreation = path; }
@@ -407,7 +407,7 @@ protected:
/* update progress status */
void newState( int progress, const TQString& synctqStatus );
/** See if there is a better tqparent then this folder */
KMFolderCachedImap* findParent( const TQString& path, const TQString& name );
@@ -324,7 +324,7 @@ public:
/**
* Specify an imap path that is used to create the folder on the server
- * Otherwise the tqparent folder is used to construct the path
+ * Otherwise the parent folder is used to construct the path
*/
const TQString& imapPathForCreation() { return mImapPathCreation; }
@@ -407,7 +407,7 @@ protected:
/* update progress status */
void newState( int progress, const TQString& synctqStatus );
- /** See if there is a better tqparent then this folder */
+ /** See if there is a better parent then this folder */
KMFolderCachedImap* findParent( const TQString& path, const TQString& name );